summaryrefslogtreecommitdiff
path: root/sql/item_geofunc.cc
diff options
context:
space:
mode:
authorpaul@ice.snake.net <>2004-07-02 16:22:46 -0500
committerpaul@ice.snake.net <>2004-07-02 16:22:46 -0500
commit8ead38a5dc155d37120751850616d5a7185bb05f (patch)
treebc1155f7ad87758a22b9373655a9de778efbf734 /sql/item_geofunc.cc
parentb10c110b189ae6d2d77e653896484c53d57d5efe (diff)
downloadmariadb-git-8ead38a5dc155d37120751850616d5a7185bb05f.tar.gz
item_geofunc.cc:
Minor comment tweaks.
Diffstat (limited to 'sql/item_geofunc.cc')
-rw-r--r--sql/item_geofunc.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/sql/item_geofunc.cc b/sql/item_geofunc.cc
index d95271a54bb..66a223f0ebf 100644
--- a/sql/item_geofunc.cc
+++ b/sql/item_geofunc.cc
@@ -313,12 +313,12 @@ err:
/*
- Functions to concatinate various spatial objects
+ Functions to concatenate various spatial objects
*/
/*
* Concatinate doubles into Point
*/
@@ -343,7 +343,7 @@ String *Item_func_point::val_str(String *str)
/*
- Concatinates various items into various collections
+ Concatenates various items into various collections
with checkings for valid wkb type of items.
For example, MultiPoint can be a collection of Points only.
coll_type contains wkb type of target collection.
@@ -388,7 +388,7 @@ String *Item_func_spatial_collection::val_str(String *str)
const char *data= res->ptr() + 1;
/*
- In the case of named collection we must to check that items
+ In the case of named collection we must check that items
are of specific type, let's do this checking now
*/
@@ -313,12 +313,12 @@ err:
*/
/*
-* Concatinate doubles into Point
+* Concatenate doubles into Point
*/